==> hazelcast-all-3.5.3-sources.jar: com/hazelcast/map/impl/client/MapSQLQueryRequest.java <==
/*
 * Copyright (c) 2008-2015, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.client;

import com.hazelcast.map.impl.MapPortableHook;
import com.hazelcast.nio.serialization.PortableReader;
import com.hazelcast.nio.serialization.PortableWriter;
import com.hazelcast.query.Predicate;
import com.hazelcast.query.SqlPredicate;
import com.hazelcast.util.IterationType;
import java.io.IOException;

public final class MapSQLQueryRequest extends AbstractMapQueryRequest {

    private String sql;

    public MapSQLQueryRequest() {
    }

    public MapSQLQueryRequest(String name, String sql, IterationType iterationType) {
        super(name, iterationType);
        this.sql = sql;
    }

    @Override
    protected Predicate getPredicate() {
        return new SqlPredicate(sql);
    }

    public int getClassId() {
        return MapPortableHook.SQL_QUERY;
    }

    protected void writePortableInner(PortableWriter writer) throws IOException {
        writer.writeUTF("sql", sql);
    }

    protected void readPortableInner(PortableReader reader) throws IOException {
        sql = reader.readUTF("sql");
    }
}

==> hazelcast-all-3.6-sources.jar: com/hazelcast/map/impl/client/MapSQLQueryRequest.java <==
/*
 * Copyright (c) 2008-2015, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.client;

import com.hazelcast.map.impl.MapPortableHook;
import com.hazelcast.nio.serialization.PortableReader;
import com.hazelcast.nio.serialization.PortableWriter;
import com.hazelcast.query.Predicate;
import com.hazelcast.query.SqlPredicate;
import com.hazelcast.query.TruePredicate;
import com.hazelcast.util.IterationType;
import com.hazelcast.util.StringUtil;

import java.io.IOException;

public final class MapSQLQueryRequest extends AbstractMapQueryRequest {

    private String sql;

    public MapSQLQueryRequest() {
    }

    public MapSQLQueryRequest(String name, String sql, IterationType iterationType) {
        super(name, iterationType);
        this.sql = sql;
    }

    @Override
    protected Predicate getPredicate() {
        if (StringUtil.isNullOrEmpty(sql)) {
            return TruePredicate.INSTANCE;
        }
        return new SqlPredicate(sql);
    }

    public int getClassId() {
        return MapPortableHook.SQL_QUERY;
    }

    protected void writePortableInner(PortableWriter writer) throws IOException {
        writer.writeUTF("sql", sql);
    }

    protected void readPortableInner(PortableReader reader) throws IOException {
        sql = reader.readUTF("sql");
    }
}
